@@ -4,7 +4,7 @@ package WebService::Avalara::AvaTax;
 
 use Modern::Perl '2011';    ## no critic (Modules::ProhibitUseQuotedVersion)
 
-our $VERSION = '0.012';     # VERSION
+our $VERSION = '0.013';     # VERSION
 use utf8;
 
 #pod =head1 SYNOPSIS
@@ -129,8 +129,9 @@ sub _new_service {
 #pod containing the results of the SOAP call; in list context they return the
 #pod results hashref and an
 #pod L<XML::Compile::SOAP::Trace|XML::Compile::SOAP::Trace>
-#pod object suitable for debugging and exception handling. If there is no result
-#pod then an exception will be thrown.
+#pod object suitable for debugging and exception handling.
+#pod
+#pod If there is no result then you should check the trace object for why.
 #pod
 #pod Please consult the
 #pod L<Avalara SOAP API reference|http://developer.avalara.com/api-reference>
@@ -258,12 +259,10 @@ sub _method_closure {
                 },
             },
         );
-
-        if ( not $answer_ref ) {
-            for ( $trace->errors ) { $_->throw }
+        if ( 'HASH' eq ref $answer_ref ) {
+            $answer_ref
+                = $answer_ref->{parameters}{ $operation->name . 'Result' };
         }
-        $answer_ref
-            = $answer_ref->{parameters}{ $operation->name . 'Result' };
         return wantarray ? ( $answer_ref, $trace ) : $answer_ref;
     };
 }
@@ -295,7 +294,7 @@ WebService::Avalara::AvaTax - Avalara SOAP interface as compiled Perl methods
 
 =head1 VERSION
 
-version 0.012
+version 0.013
 
 =head1 SYNOPSIS
 
@@ -328,8 +327,9 @@ necessary parameters. In scalar context they return a reference to a hash
 containing the results of the SOAP call; in list context they return the
 results hashref and an
 L<XML::Compile::SOAP::Trace|XML::Compile::SOAP::Trace>
-object suitable for debugging and exception handling. If there is no result
-then an exception will be thrown.
+object suitable for debugging and exception handling.
+
+If there is no result then you should check the trace object for why.
 
 Please consult the
 L<Avalara SOAP API reference|http://developer.avalara.com/api-reference>
